pub(crate) enum ChunkEncryptionResult {
NeedMoreData,
EncryptedChunk(Vec<u8>),
FinalEncryptedChunk(Vec<u8>),
Error(StreamEncryptionError),
}Expand description
Outcome of feeding one chunk of plaintext to a StreamingEncryptor::update.
Variants
NeedMoreData
The encryptor needs more input bytes before it can produce ciphertext.
EncryptedChunk(Vec<u8>)
A chunk of the ciphertext is emitted, but the stream is not yet complete
FinalEncryptedChunk(Vec<u8>)
The last chunk is emitted and the stream is completed. No more calls to update should be
made after this.
Error(StreamEncryptionError)
Encryption failed. Discard the entire stream.